@@ -7,12 +7,12 @@ use Carp;
 #==================================================================
 # Author    : Djibril Ousmanou
 # Copyright : 2010
-# Update    : 23/10/2010 11:18:35
+# Update    : 24/10/2010 12:44:54
 # AIM       : Create bars graph
 #==================================================================
 
 use vars qw($VERSION);
-$VERSION = '1.01';
+$VERSION = '1.02';
 
 use base qw/ Tk::Derived Tk::Canvas::GradientColor /;
 use Tk::Balloon;
@@ -330,6 +330,7 @@ sub _ViewLegend {
   my $legendfont         = $CompositeWidget->{RefChart}->{Legend}{legendfont};
   my $titlecolor         = $CompositeWidget->{RefChart}->{Legend}{titlecolors};
   my $titlefont          = $CompositeWidget->{RefChart}->{Legend}{titlefont};
+  my $axiscolor          = $CompositeWidget->cget( -axiscolor );
 
   # display legend title
   if ( defined $LegendTitle ) {
@@ -462,6 +463,7 @@ sub _ViewLegend {
     -tags => [
       $CompositeWidget->{RefChart}->{TAGS}{BoxLegend}, $CompositeWidget->{RefChart}->{TAGS}{AllTagsChart},
     ],
+    -outline => $axiscolor,
   );
 
   return;
@@ -472,7 +474,7 @@ sub _axis {
 
   my $axiscolor = $CompositeWidget->cget( -axiscolor );
 
-  # x axis width
+  # x-axis width
   $CompositeWidget->{RefChart}->{Axis}{Xaxis}{Width}
     = $CompositeWidget->{RefChart}->{Canvas}{Width}
     - ( 2 * $CompositeWidget->{RefChart}->{Canvas}{WidthEmptySpace}
@@ -485,7 +487,7 @@ sub _axis {
     $CompositeWidget->_Legend( $CompositeWidget->{RefChart}->{Legend}{DataLegend} );
   }
 
-  # Height y axis
+  # Height y-axis
   $CompositeWidget->{RefChart}->{Axis}{Yaxis}{Height}
     = $CompositeWidget->{RefChart}->{Canvas}{Height}    # Largeur canvas
     - (
@@ -536,7 +538,7 @@ sub _axis {
   $CompositeWidget->{RefChart}->{Axis}{CxMax}
     = $CompositeWidget->{RefChart}->{Axis}{CxMin} + $CompositeWidget->{RefChart}->{Axis}{Xaxis}{Width};
 
-  # Bottom x axis
+  # Bottom x-axis
   $CompositeWidget->createLine(
     $CompositeWidget->{RefChart}->{Axis}{CxMin},
     $CompositeWidget->{RefChart}->{Axis}{CyMin},
@@ -591,11 +593,11 @@ sub _xtick {
   my $xvaluecolor = $CompositeWidget->cget( -xvaluecolor );
   my $longticks   = $CompositeWidget->cget( -longticks );
 
-  # x coordinates y ticks on bottom x axis
+  # x coordinates y ticks on bottom x-axis
   my $Xtickx1 = $CompositeWidget->{RefChart}->{Axis}{CxMin};
   my $Xticky1 = $CompositeWidget->{RefChart}->{Axis}{CyMin};
 
-  # x coordinates y ticks on 0,0 x axis if the graph have only y value < 0
+  # x coordinates y ticks on 0,0 x-axis if the graph have only y value < 0
   if (  $CompositeWidget->cget( -zeroaxisonly ) == 1
     and $CompositeWidget->{RefChart}->{Data}{MaxYValue} > 0 )
   {
@@ -679,7 +681,7 @@ sub _ViewData {
   my $outlinebar         = $CompositeWidget->cget( -outlinebar );
   my $barsvaluescolor    = $CompositeWidget->cget( -barsvaluescolor );
 
-  # number of value for x axis
+  # number of value for x-axis
   $CompositeWidget->{RefChart}->{Data}{xtickNumber} = $CompositeWidget->{RefChart}->{Data}{NumberXValues};
 
   # Space between x ticks
@@ -1507,9 +1509,9 @@ Default : B<#B3B3B3>
 
 Draw the axes as a box.
 
- -boxaxis => 0, #  0 or 1
+ -boxaxis => 1, #  0 or 1
 
-Default : B<1>
+Default : B<0>
 
 =item Name:	B<Noaxis>
 
@@ -1973,9 +1975,9 @@ Default : B<{Times} 8 {normal}>
 
 Set a box around all legend.
 
- -box => 0,
+ -box => 1, # or 0
 
-Default : B<1>
+Default : B<0>
 
 =item *
 
@@ -2011,7 +2013,7 @@ Default : B<30>
 
 =head2 zoom
 
-zoom the graph. The x axis and y axis will be zoomed. If your graph has a 300*300 
+Zoom the graph. The x-axis and y-axis will be zoomed. If your graph has a 300*300 
 size, after a zoom(200), the graph will have a 600*600 size.
 
 $Chart->zoom(I<$zoom>);
@@ -2029,7 +2031,7 @@ $zoom must be an integer great than 0.
 
 =head2 zoomx
 
-zoom the graph the x axis.
+Zoom the graph the x-axis.
 
  # original canvas size 300*300
  $Chart->zoomx(50); # new size : 150*300
@@ -2038,13 +2040,24 @@ zoom the graph the x axis.
 
 =head2 zoomy
 
-zoom the graph the y axis.
+Zoom the graph the y-axis.
 
  # original canvas size 300*300
  $Chart->zoomy(50); # new size : 300*150
  ...
  $Chart->zoom(100); # new size : 300*300
 
+=head1 EXAMPLES
+
+In the B<demo> directory, you have a lot of script examples with their screenshot. 
+See also the L<http://search.cpan.org/dist/Tk-Chart/MANIFEST> web page of L<Tk::Chart>.
+
+=head1 SEE ALSO
+
+See L<Tk::Canvas> for details of the standard options.
+
+See L<Tk::Chart>, L<Tk::Chart::FAQ>, L<GD::Graph>, L<Tk::Graph>.
+
 =head1 AUTHOR
 
 Djibril Ousmanou, C<< <djibel at cpan.org> >>
@@ -2055,192 +2068,6 @@ Please report any bugs or feature requests to C<bug-Tk-Chart at rt.cpan.org>, or
 the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Tk-Chart>.  I will be notified, and then you'll
 automatically be notified of progress on your bug as I make changes.
 
-=head1 EXAMPLES
-
-overwrite option
-
-  #!/usr/bin/perl
-  use strict;
-  use warnings;
-  use Tk;
-  use Tk::Chart::Bars;
-  
-  my $mw = new MainWindow(
-    -title      => 'Tk::Chart::Bars - overwrite',
-    -background => 'white',
-  );
-  
-  my $Chart = $mw->Bars(
-    -title     => 'My graph title - overwrite',
-    -xlabel    => 'X Label',
-    -ylabel    => 'Y Label',
-    -overwrite => 1
-  )->pack(qw / -fill both -expand 1 /);
-  
-  my @data = (
-    [ '1st', '2nd', '3rd', '4th', '5th', '6th', '7th', '8th', '9th' ],
-    [ 4,     0,     16,    2,     3,     5.5,   7,     5,     02 ],
-    [ 1,     2,     4,     6,     3,     17.5,  1,     20,    10 ]
-  );
-  
-  # Create the graph
-  $Chart->plot( \@data );
-  
-  MainLoop();
-
-Cumulate and create a zoom Menu with the graph.
-
-  #!/usr/bin/perl
-  use strict;
-  use warnings;
-  use Tk;
-  use Tk::Chart::Bars;
-
-  my $mw = new MainWindow(
-    -title      => 'Tk::Chart::Bars - cumulate + zoom menu',
-    -background => 'white',
-  );
-
-  my $Chart = $mw->Bars(
-    -title        => 'My graph title',
-    -xlabel       => 'X Label',
-    -ylabel       => 'Y Label',
-    -linewidth    => 2,
-    -zeroaxisonly => 1,
-    -cumulate     => 1,
-  )->pack(qw / -fill both -expand 1 /);
-
-  my @data = (
-    [ '1st', '2nd', '3rd', '4th', '5th', '6th', '7th', '8th', '9th' ],
-    [ 1,     2,     5,     6,    3,     1.5,   1,     3,     4 ],
-    [ 4,     0,     16,    2,     3,     5.5,   7,     5,     02 ],
-    [ 1,     2,     4,     6,     3,     17.5,  1,     20,    10 ]
-  );
-
-  # Add a legend to our graph
-  my @Legends = ( 'legend 1', 'legend 2', 'legend 3' );
-  $Chart->set_legend(
-    -title       => 'Title legend',
-    -data        => \@Legends,
-    -titlecolors => 'blue',
-  );
-
-  # I can see the legend text when mouse pass on line and
-  # the line change color when mouse pass on legend text
-  $Chart->set_balloon();
-
-  # Create the graph
-  $Chart->plot( \@data );
-
-  $Chart->add_data( [ 1 .. 9 ], 'leg4' );
-
-  my $menu = Menu( $Chart, [qw/30 50 80 100 150 200/] );
-
-  MainLoop();
-
-  sub CanvasMenu {
-    my ( $Canvas, $x, $y, $CanvasMenu ) = @_;
-    $CanvasMenu->post( $x, $y );
-
-    return;
-  }
-
-  sub Menu {
-    my ( $Chart, $RefData ) = @_;
-    my %MenuConfig = (
-      -tearoff    => 0,
-      -takefocus  => 1,
-      -background => 'white',
-      -menuitems  => [],
-    );
-    my $Menu = $Chart->Menu(%MenuConfig);
-    $Menu->add( 'cascade', -label => 'Zoom' );
-    $Menu->add( 'cascade', -label => 'Zoom X-axis' );
-    $Menu->add( 'cascade', -label => 'Zoom Y-axis' );
-
-    my $SsMenuZoomX = $Menu->Menu(%MenuConfig);
-    my $SsMenuZoomY = $Menu->Menu(%MenuConfig);
-    my $SsMenuZoom  = $Menu->Menu(%MenuConfig);
-
-    for my $Zoom ( @{$RefData} ) {
-      $SsMenuZoom->add(
-        'command',
-        -label   => "$Zoom \%",
-        -command => sub { $Chart->zoom($Zoom); }
-      );
-      $SsMenuZoomX->add(
-        'command',
-        -label   => "$Zoom \%",
-        -command => sub { $Chart->zoomx($Zoom); }
-      );
-      $SsMenuZoomY->add(
-        'command',
-        -label   => "$Zoom \%",
-        -command => sub { $Chart->zoomy($Zoom); }
-      );
-
-    }
-
-    $Menu->entryconfigure( 'Zoom X-axis', -menu => $SsMenuZoomX );
-    $Menu->entryconfigure( 'Zoom Y-axis', -menu => $SsMenuZoomY );
-    $Menu->entryconfigure( 'Zoom',        -menu => $SsMenuZoom );
-
-    $Chart->Tk::bind( '<ButtonPress-3>',
-      [ \&CanvasMenu, Ev('X'), Ev('Y'), $Menu, $Chart ] );
-
-    return $Menu;
-  }
-
-No spacingbar and show values
-
-  #!/usr/bin/perl
-  use strict;
-  use warnings;
-  use Tk;
-  use Tk::Chart::Bars;
-
-  my $mw = new MainWindow(
-    -title      => 'Tk::Chart::Bars - no spacingbar',
-    -background => 'white',
-  );
-  my $Chart = $mw->Bars(
-    -title      => 'My graph title',
-    -xlabel     => 'X Label',
-    -ylabel     => 'Y Label',
-    -spacingbar => 0,
-    -showvalues => 1,
-  )->pack(qw / -fill both -expand 1 /);
-
-  my @data = (
-    [ '1st', '2nd', '3rd', '4th', '5th', '6th', '7th', '8th', '9th' ],
-    [ 1,     2,     5,     6,     3,     1.5,   1,     3,     4 ],
-    [ 4,     2,     5,     2,     3,     5.5,   7,     9,     4 ],
-    [ 1,     2,     52,    6,     3,     17.5,  1,     43,    10 ]
-  );
-
-  # Add a legend to the graph
-  my @Legends = ( 'legend 1', 'legend 2', 'legend 3' );
-  $Chart->set_legend(
-    -title       => 'Title legend',
-    -data        => \@Legends,
-    -titlecolors => 'blue',
-  );
-
-  # Add help identification
-  $Chart->set_balloon();
-
-  # Create the graph
-  $Chart->plot( \@data );
-
-  MainLoop();
-
-
-=head1 SEE ALSO
-
-See L<Tk::Canvas> for details of the standard options.
-
-See L<Tk::Chart>, L<Tk::Chart::FAQ>, L<GD::Graph>, L<Tk::Graph>.
-
 =head1 SUPPORT
 
 You can find documentation for this module with the perldoc command.
