@@ -7,12 +7,12 @@ use Carp;
 #==================================================================
 # Author    : Djibril Ousmanou
 # Copyright : 2010
-# Update    : 23/10/2010 11:18:19
+# Update    : 24/10/2010 12:45:47
 # AIM       : Create Mixed graph
 #==================================================================
 
 use vars qw($VERSION);
-$VERSION = '1.01';
+$VERSION = '1.02';
 
 use base qw/ Tk::Derived Tk::Canvas::GradientColor /;
 use Tk::Balloon;
@@ -360,6 +360,7 @@ sub _ViewLegend {
   my $legendfont         = $CompositeWidget->{RefChart}->{Legend}{legendfont};
   my $titlecolor         = $CompositeWidget->{RefChart}->{Legend}{titlecolors};
   my $titlefont          = $CompositeWidget->{RefChart}->{Legend}{titlefont};
+  my $axiscolor          = $CompositeWidget->cget( -axiscolor );
 
   # display legend title
   if ( defined $LegendTitle ) {
@@ -539,6 +540,7 @@ sub _ViewLegend {
     -tags => [
       $CompositeWidget->{RefChart}->{TAGS}{BoxLegend}, $CompositeWidget->{RefChart}->{TAGS}{AllTagsChart},
     ],
+    -outline => $axiscolor,
   );
 
   return;
@@ -549,7 +551,7 @@ sub _axis {
 
   my $axiscolor = $CompositeWidget->cget( -axiscolor );
 
-  # x axis width
+  # x-axis width
   $CompositeWidget->{RefChart}->{Axis}{Xaxis}{Width}
     = $CompositeWidget->{RefChart}->{Canvas}{Width}
     - ( 2 * $CompositeWidget->{RefChart}->{Canvas}{WidthEmptySpace}
@@ -562,7 +564,7 @@ sub _axis {
     $CompositeWidget->_Legend( $CompositeWidget->{RefChart}->{Legend}{DataLegend} );
   }
 
-  # Height y axis
+  # Height y-axis
   $CompositeWidget->{RefChart}->{Axis}{Yaxis}{Height}
     = $CompositeWidget->{RefChart}->{Canvas}{Height}    # Largeur canvas
     - (
@@ -613,7 +615,7 @@ sub _axis {
   $CompositeWidget->{RefChart}->{Axis}{CxMax}
     = $CompositeWidget->{RefChart}->{Axis}{CxMin} + $CompositeWidget->{RefChart}->{Axis}{Xaxis}{Width};
 
-  # Bottom x axis
+  # Bottom x-axis
   $CompositeWidget->createLine(
     $CompositeWidget->{RefChart}->{Axis}{CxMin},
     $CompositeWidget->{RefChart}->{Axis}{CyMin},
@@ -668,11 +670,11 @@ sub _xtick {
   my $xvaluecolor = $CompositeWidget->cget( -xvaluecolor );
   my $longticks   = $CompositeWidget->cget( -longticks );
 
-  # x coordinates y ticks on bottom x axis
+  # x coordinates y ticks on bottom x-axis
   my $Xtickx1 = $CompositeWidget->{RefChart}->{Axis}{CxMin};
   my $Xticky1 = $CompositeWidget->{RefChart}->{Axis}{CyMin};
 
-  # x coordinates y ticks on 0,0 x axis if the graph have only y value < 0
+  # x coordinates y ticks on 0,0 x-axis if the graph have only y value < 0
   if (  $CompositeWidget->cget( -zeroaxisonly ) == 1
     and $CompositeWidget->{RefChart}->{Data}{MaxYValue} > 0 )
   {
@@ -753,7 +755,7 @@ sub _ViewData {
 
   my $RefData = $CompositeWidget->{RefChart}->{Data}{RefAllData};
 
-  # number of value for x axis
+  # number of value for x-axis
   $CompositeWidget->{RefChart}->{Data}{xtickNumber} = $CompositeWidget->{RefChart}->{Data}{NumberXValues};
 
   # Space between x ticks
@@ -825,7 +827,7 @@ sub _ViewDataAreas {
   my @PointsData;    # coordinate x and y
   my @DashPointsxLines;
 
-  # First point, in x axis
+  # First point, in x-axis
   my $Fisrtx
     = $CompositeWidget->{RefChart}->{Axis}{Cx0}
     + $CompositeWidget->{RefChart}->{Axis}{Xaxis}{SpaceBetweenTick}
@@ -865,7 +867,7 @@ sub _ViewDataAreas {
     $NumberData++;
   }
 
-  # Last point, in x axis
+  # Last point, in x-axis
   my $Lastx
     = $CompositeWidget->{RefChart}->{Axis}{Cx0}
     + ( $NumberData - 1 ) * $CompositeWidget->{RefChart}->{Axis}{Xaxis}{SpaceBetweenTick}
@@ -1921,9 +1923,9 @@ Default : B<#B3B3B3>
 
 Draw the axes as a box.
 
- -boxaxis => 0, #  0 or 1
+ -boxaxis => 1, #  0 or 1
 
-Default : B<1>
+Default : B<0>
 
 =item Name:	B<Noaxis>
 
@@ -2563,9 +2565,9 @@ Default : B<{Times} 8 {normal}>
 
 Set a box around all legend.
 
- -box => 0,
+ -box => 1, # or 0
 
-Default : B<1>
+Default : B<0>
 
 =item *
 
@@ -2601,7 +2603,7 @@ Default : B<30>
 
 =head2 zoom
 
-zoom the graph. The x axis and y axis will be zoomed. If your graph has a 300*300 
+Zoom the graph. The x-axis and y-axis will be zoomed. If your graph has a 300*300 
 size, after a zoom(200), the graph will have a 600*600 size.
 
 $Chart->zoom(I<$zoom>);
@@ -2619,7 +2621,7 @@ $zoom must be an integer great than 0.
 
 =head2 zoomx
 
-zoom the graph the x axis.
+Zoom the graph the x-axis.
 
  # original canvas size 300*300
  $Chart->zoomx(50); # new size : 150*300
@@ -2628,13 +2630,24 @@ zoom the graph the x axis.
 
 =head2 zoomy
 
-zoom the graph the y axis.
+Zoom the graph the y-axis.
 
  # original canvas size 300*300
  $Chart->zoomy(50); # new size : 300*150
  ...
  $Chart->zoom(100); # new size : 300*300
 
+=head1 EXAMPLES
+
+In the B<demo> directory, you have a lot of script examples with their screenshot. 
+See also the L<http://search.cpan.org/dist/Tk-Chart/MANIFEST> web page of L<Tk::Chart>.
+
+=head1 SEE ALSO
+
+See L<Tk::Canvas> for details of the standard options.
+
+See L<Tk::Chart>, L<Tk::Chart::FAQ>, L<GD::Graph>, L<Tk::Graph>.
+
 =head1 AUTHOR
 
 Djibril Ousmanou, C<< <djibel at cpan.org> >>
@@ -2645,13 +2658,6 @@ Please report any bugs or feature requests to C<bug-Tk-Chart at rt.cpan.org>, or
 the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Tk-Chart>.  I will be notified, and then you'll
 automatically be notified of progress on your bug as I make changes.
 
-
-=head1 SEE ALSO
-
-See L<Tk::Canvas> for details of the standard options.
-
-See L<Tk::Chart>, L<Tk::Chart::FAQ>, L<GD::Graph>, L<Tk::Graph>.
-
 =head1 SUPPORT
 
 You can find documentation for this module with the perldoc command.
